@@ -1,6 +1,7 @@
 from avatar_utils.db.mixins.created_at import CreatedAtMixin
 from avatar_utils.db.mixins.crud import CRUDMixin
 from avatar_utils.db.mixins.json_cast import JsonCastMixin
+from avatar_utils.db.mixins.sso_user import SSOUserMixin
 from avatar_utils.db.mixins.time_cast import TimeCastMixin
 
 __all__ = [
@@ -8,4 +9,5 @@ __all__ = [
     'CRUDMixin',
     'JsonCastMixin',
     'TimeCastMixin',
+    'SSOUserMixin',
 ]
