@@ -1,3 +1,4 @@
+from datetime import timedelta
 from logging import getLogger
 
 from flask import g
@@ -7,6 +8,7 @@ from sqlalchemy.exc import DatabaseError
 from app import db
 from . import logs
 from .models import Log
+from ..core import create_response
 
 logger = getLogger(__name__)
 
@@ -38,3 +40,14 @@ def after_request(response):
     except BaseException as err:
         logger.error(f'{log_prefix} < Error occurs: {err}')
     return response
+
+
+@logs.route('/logs/prune', methods=['POST'])
+def logs_prune():
+    default_interval = timedelta(days=30)
+
+    logger.debug('Pruning logs with interval = %s', default_interval)
+
+    Log.prune(default_interval)
+
+    return create_response()
