@@ -51,20 +51,17 @@ class Serializable:
         data_copy = deepcopy(data)
 
         if isinstance(data_copy, Serializable):
-            res = data_copy.to_dict(remove_defaults=remove_defaults)
-            return res
+            return data_copy.to_dict(remove_defaults=remove_defaults)
+
         elif isinstance(data_copy, list):
             for i in range(len(data_copy)):
                 data_copy[i] = Serializable.any_to_dict(data=data_copy[i], remove_defaults=remove_defaults)
-            return data_copy
+
         elif isinstance(data_copy, dict):
             for key, value in data_copy.items():
                 data_copy[key] = Serializable.any_to_dict(value, remove_defaults=remove_defaults)
-            return data_copy
-        elif data_copy is None or isinstance(data_copy, bool) or isinstance(data_copy, str):
-            return data_copy
-        else:
-            raise NotImplementedError
+
+        return data_copy
 
     # все вложенные объекты десериализуются как Serializable, то есть у них должно быть поле repr_type
     @classmethod
