@@ -3,9 +3,9 @@ from functools import wraps
 from logging import getLogger
 from typing import Type, Optional, Union, Callable, Tuple, Sequence
 
+import marshmallow
 from flask import request, jsonify
 from marshmallow import Schema
-from marshmallow import ValidationError
 from sqlalchemy.exc import DatabaseError
 from werkzeug import Response, exceptions  # noqa: PyPackageRequirements
 
@@ -72,15 +72,17 @@ def validate_json(request_schema: Optional[Type[Schema]] = None,
                     if response.status_code != ServiceHTTPCodes.OK.value:
                         return response, status
 
-                    data = validation_schema.load(response.json)
+                    validation_schema.load(response.json)
                     logger.debug(f'{log_prefix} response validated')
-                    response = jsonify(validation_schema.dump(data))
+
+                    # return original json cause validation_schema.dump adds unnecessary fields
+                    response = response.json
 
             except exceptions.BadRequest as err:
                 logger.warning(f'{log_prefix} < Step: {step}. Exception: {err}')
                 response, status = create_response(status=ServiceHTTPCodes.BAD_REQUEST.value,
                                                    message='invalid requests body')
-            except ValidationError as err:
+            except marshmallow.ValidationError as err:
                 logger.warning(f'{log_prefix} < Step: {step}. Exception: {err}')
                 response, status = create_response(status=ServiceHTTPCodes.UNPROCESSABLE_ENTITY.value,
                                                    message='validation error',
@@ -90,6 +92,10 @@ def validate_json(request_schema: Optional[Type[Schema]] = None,
                 response, status = create_response(status=ServiceHTTPCodes.NOT_IMPLEMENTED.value,
                                                    message=type(err).__name__,
                                                    data=dict(traceback=str(traceback.format_exc())))
+            # except TimeoutError as err:
+            #     logger.error('Database is not available due to err: %s. Exiting', err)
+            #     exit(1)
+
             except DatabaseError as err:
                 logger.warning(f'{log_prefix} < Step: {step}. Exception: {err}')
                 try:
